mcst-linux-kernel/patches-2024.06.26/cpu-1.4.3/0012-spelling.patch

68 lines
2.2 KiB
Diff

Description: fix typos and an error from man, all found by lintian
Author: Florian Schlichting <fsfs@debian.org>
--- a/doc/man/cpu.8
+++ b/doc/man/cpu.8
@@ -32,7 +32,7 @@
.SH AUTHORS
Blake Matheny <bmatheny@purdue.edu>
-The current version of this software is always availabe at
+The current version of this software is always available at
.I http://cpu.sourceforge.net
.SH BUGS
--- a/doc/man/cpu.conf.5
+++ b/doc/man/cpu.conf.5
@@ -131,7 +131,7 @@
placed in the group whose gid is USER_GID.
.IP "\fBUSERS_GID\fR = \fB integer\fR"
If \fBUSERGROUPS\fR is no, then \fBUSERS_GID\fR should be the GID of the group
-'users' (or the equivalent group) on your system. If this is unspecified, the
+\'users\' (or the equivalent group) on your system. If this is unspecified, the
default is 100.
.IP "\fBGECOS\fR = \fBstring\fR"
The default value for a user's gecos field. This can be overridden at the
@@ -187,7 +187,7 @@
.SH AUTHORS
Blake Matheny <bmatheny@purdue.edu>
-The current version of this software is always availabe at
+The current version of this software is always available at
.I http://cpu.sourceforge.net
.SH BUGS
--- a/ltmain.sh
+++ b/ltmain.sh
@@ -2584,7 +2584,7 @@
fi
done
else
- # Error occured in the first compile. Let's try to salvage
+ # Error occurred in the first compile. Let's try to salvage
# the situation: Compile a separate program for each library.
for i in $deplibs; do
name="`expr $i : '-l\(.*\)'`"
--- a/src/plugins/ldap/ld.c
+++ b/src/plugins/ldap/ld.c
@@ -909,8 +909,8 @@
Free (filter);
CPU_ldapPerror (ld, globalLdap, "getNextLinearUid: ldap_result");
return -1;
- case 0: /* continue, timeout occured */
- printf("Timeout occured\n");
+ case 0: /* continue, timeout occurred */
+ printf("Timeout occurred\n");
break;
case LDAP_RES_SEARCH_ENTRY: /* server returned an entry */
a = ldap_first_attribute (ld, pos, &ber);
@@ -1115,7 +1115,7 @@
Free (filter);
CPU_ldapPerror (ld, globalLdap, "getNextLinearGid: ldap_result");
return -1;
- case 0: /* continue, timeout occured */
+ case 0: /* continue, timeout occurred */
break;
case LDAP_RES_SEARCH_ENTRY: /* server returned an entry */
a = ldap_first_attribute (ld, pos, &ber);